==> haskell-free-5.2-115-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 free
version:              5.2
visibility:           public
id:                   free-5.2-LavBzzjIwTh2GJScdhp5qt
key:                  free-5.2-LavBzzjIwTh2GJScdhp5qt
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/free/
synopsis:             Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.

    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.

    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.

    More information on free monads, including examples, can be found in the
    following blog posts:
    <https://ekmett.github.io/reader/2008/monads-for-free/>
    <https://ekmett.github.io/reader/2011/free-monads-for-less/>

category:             Control, Monads
abi:                  9368f1b284c06dfb6d88e05761e04751
exposed:              True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter

import-dirs:          /usr/lib/ghc-9.4.8/site-local/free-5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/free-5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/free-5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-free
hs-libraries:         HSfree-5.2-LavBzzjIwTh2GJScdhp5qt
depends:
    base-4.17.2.1 comonad-5.0.9-69ztrEylAHVD4BHHoJEwKX containers-0.6.7
    distributive-0.6.2.1-3469zRFAXaLLtl1TZCSnJt exceptions-0.10.5
    indexed-traversable-0.1.4-KvS9wRlCKDWFRGYTEgz6lC mtl-2.2.2
    profunctors-5.6.3-GJws21l5du15P9B6ShOpfs
    semigroupoids-6.0.1-Bxz0f1JNfGSLvZg0Ig0I9J
    template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2
    transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA

haddock-interfaces:   /usr/share/doc/haskell-free/html/free.haddock
haddock-html:         /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-5.2-120-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 free
version:              5.2
visibility:           public
id:                   free-5.2-GjBgjt73BB74JXsIg5MCCe
key:                  free-5.2-GjBgjt73BB74JXsIg5MCCe
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/free/
synopsis:             Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.

    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.

    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.

    More information on free monads, including examples, can be found in the
    following blog posts:
    <https://ekmett.github.io/reader/2008/monads-for-free/>
    <https://ekmett.github.io/reader/2011/free-monads-for-less/>

category:             Control, Monads
abi:                  e8c2626e642599fc17acae174e66074f
exposed:              True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/free-5.2
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/free-5.2
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/free-5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-free
hs-libraries:         HSfree-5.2-GjBgjt73BB74JXsIg5MCCe
depends:
    base-4.18.3.0 comonad-5.0.9-Ij6ay3F3LyzKQb79LuZSMO containers-0.6.7
    distributive-0.6.2.1-8SDqINKdPq1LgZ8NLMuGmw exceptions-0.10.7
    indexed-traversable-0.1.4-4WgKtUu7swysftQ0x7OdR mtl-2.3.1
    profunctors-5.6.3-2dieZj3uEeKD63E7Fw43mp
    semigroupoids-6.0.1-HDr1Vl4bsU6CmLVz8mRz3I
    template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-JZUv7luqGYXIX6vHGniH2t transformers-0.6.1.0
    transformers-base-0.4.6-KecQozQ2bJs3HLDcaEYSEy

haddock-interfaces:   /usr/share/doc/haskell-free/html/free.haddock
haddock-html:         /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
